import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'amap_location_option.dart';
import 'amap_location_plugin_method_channel.dart';

abstract class AmapLocationPluginPlatform extends PlatformInterface {
  /// Constructs
  AmapLocationPluginPlatform() : super(token: _token);

  static final Object _token = Object();

  static AmapLocationPluginPlatform _instance =
      AmapLocationPluginMethodChannel();

  static AmapLocationPluginPlatform get instance => _instance;

  static set instance(AmapLocationPluginPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  /// 初始化key
  void initKey() {
    throw UnimplementedError('initKey() has not been implemented.');
  }

  /// iOS 14中系统的定位类型信息
  Future<AMapAccuracyAuthorization> getSystemAccuracyAuthorization() {
    throw UnimplementedError(
        'getSystemAccuracyAuthorization() has not been implemented.');
  }

  /// 开始定位
  void startLocation() {
    throw UnimplementedError('startLocation() has not been implemented.');
  }

  /// 停止定位
  void stopLocation() {
    throw UnimplementedError('stopLocation() has not been implemented.');
  }

  /// 计算2点之间的距离
  Future<double> calculateDistance(
      double lat1, double lon1, double lat2, double lon2) {
    throw UnimplementedError('calculateDistance() has not been implemented.');
  }

  ///设置Android和iOS的apikey，建议在weigdet初始化时设置<br>
  ///apiKey的申请请参考高德开放平台官网<br>
  ///Android端: https://lbs.amap.com/api/android-location-sdk/guide/create-project/get-key<br>
  ///iOS端: https://lbs.amap.com/api/ios-location-sdk/guide/create-project/get-key<br>
  ///[androidKey] Android平台的key<br>
  ///[iosKey] ios平台的key<br>
  void setApiKey(String androidKey, String iosKey) {
    throw UnimplementedError('setApiKey() has not been implemented.');
  }

  /// 设置定位参数
  void setLocationOption(AMapLocationOption locationOption) {
    throw UnimplementedError('setLocationOption() has not been implemented.');
  }

  /// 销毁定位
  void destroy() {
    throw UnimplementedError('destroy() has not been implemented.');
  }

  ///定位结果回调
  ///
  ///定位结果以map的形式透出，其中包含的key已经含义如下：
  ///
  /// `callbackTime`:回调时间，格式为"yyyy-MM-dd HH:mm:ss"
  ///
  /// `locationTime`:定位时间， 格式为"yyyy-MM-dd HH:mm:ss"
  ///
  /// `locationType`:  定位类型， 具体类型可以参考https://lbs.amap.com/api/android-location-sdk/guide/utilities/location-type
  ///
  /// `latitude`:纬度
  ///
  /// `longitude`:精度
  ///
  /// `accuracy`:精确度
  ///
  /// `altitude`:海拔, android上只有locationType==1时才会有值
  ///
  /// `bearing`: 角度，android上只有locationType==1时才会有值
  ///
  /// `speed`:速度， android上只有locationType==1时才会有值
  ///
  /// `country`: 国家，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `province`: 省，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `city`: 城市，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `district`: 城镇（区），android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `street`: 街道，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `streetNumber`: 门牌号，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `cityCode`: 城市编码，android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `adCode`: 区域编码， android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `address`: 地址信息， android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `description`: 位置语义， android上只有通过[AMapLocationOption.needAddress]为true时才有可能返回值
  ///
  /// `errorCode`: 错误码，当定位失败时才会返回对应的错误码， 具体错误请参考：https://lbs.amap.com/api/android-location-sdk/guide/utilities/errorcode
  ///
  /// `errorInfo`: 错误信息， 当定位失败时才会返回
  Stream<Map<String, Object>> onLocationChanged() {
    throw UnimplementedError('onLocationChanged() has not been implemented.');
  }

  /// 设置是否已经包含高德隐私政策并弹窗展示显示用户查看，如果未包含或者没有弹窗展示，高德定位SDK将不会工作<br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy<br>
  /// <b>必须保证在调用定位功能之前调用， 建议首次启动App时弹出《隐私政策》并取得用户同意</b><br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy
  /// [hasContains] 隐私声明中是否包含高德隐私政策说明<br>
  /// [hasShow] 隐私权政策是否弹窗展示告知用户<br>
  void updatePrivacyShow(bool hasContains, bool hasShow) {
    throw UnimplementedError('updatePrivacyShow() has not been implemented.');
  }

  /// 设置是否已经取得用户同意，如果未取得用户同意，高德定位SDK将不会工作<br>
  /// 高德SDK合规使用方案请参考官网地址：https://lbs.amap.com/news/sdkhgsy<br>
  /// <b>必须保证在调用定位功能之前调用, 建议首次启动App时弹出《隐私政策》并取得用户同意</b><br>
  /// [hasAgree] 隐私权政策是否已经取得用户同意<br>
  void updatePrivacyAgree(bool hasAgree) {
    throw UnimplementedError('updatePrivacyAgree() has not been implemented.');
  }
}
